cuDDL
Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Friends | List of all members
cuddl::pairwise_counts Struct Reference

Raw per-bucket classification counts for one sketch pair comparison. More...

Public Member Functions

__host__ __device__ pairwise_counts & operator+= (pairwise_counts const other) noexcept
 Accumulates other into this instance (used for device reductions).
 
__host__ __device__ constexpr pairwise_counts mirrored () const noexcept
 The same comparison seen from the other sketch: lower and higher swap.
 

Public Attributes

uint32_t lower {}
 this register is strictly lower than the other's in that bucket.
 
uint32_t equal {}
 this register equals the other's in that bucket.
 
uint32_t higher {}
 this register is strictly higher than the other's in that bucket.
 
uint32_t both_empty {}
 Both registers are empty in that bucket.
 

Friends

__host__ __device__ pairwise_counts operator+ (pairwise_counts left, pairwise_counts const right) noexcept
 Sums two count sets for device reductions.
 
bool operator== (pairwise_counts const &, pairwise_counts const &)=default
 

Detailed Description

Raw per-bucket classification counts for one sketch pair comparison.

Definition at line 8 of file pairwise_counts.cuh.

Member Function Documentation

◆ mirrored()

__host__ __device__ constexpr pairwise_counts cuddl::pairwise_counts::mirrored ( ) const
inlineconstexprnoexcept

The same comparison seen from the other sketch: lower and higher swap.

Definition at line 34 of file pairwise_counts.cuh.

34 {
35 return {.lower = higher, .equal = equal, .higher = lower, .both_empty = both_empty};
36 }
uint32_t both_empty
Both registers are empty in that bucket.
uint32_t equal
this register equals the other's in that bucket.
uint32_t lower
this register is strictly lower than the other's in that bucket.
uint32_t higher
this register is strictly higher than the other's in that bucket.

◆ operator+=()

__host__ __device__ pairwise_counts & cuddl::pairwise_counts::operator+= ( pairwise_counts const  other)
inlinenoexcept

Accumulates other into this instance (used for device reductions).

Definition at line 19 of file pairwise_counts.cuh.

19 {
20 lower += other.lower;
21 equal += other.equal;
22 higher += other.higher;
23 both_empty += other.both_empty;
24 return *this;
25 }

Friends And Related Symbol Documentation

◆ operator+

__host__ __device__ pairwise_counts operator+ ( pairwise_counts  left,
pairwise_counts const  right 
)
friend

Sums two count sets for device reductions.

Definition at line 29 of file pairwise_counts.cuh.

29 {
30 return left += right;
31 }

◆ operator==

bool operator== ( pairwise_counts const &  ,
pairwise_counts const &   
)
friend

Member Data Documentation

◆ both_empty

uint32_t cuddl::pairwise_counts::both_empty {}

Both registers are empty in that bucket.

Definition at line 16 of file pairwise_counts.cuh.

16{};

◆ equal

uint32_t cuddl::pairwise_counts::equal {}

this register equals the other's in that bucket.

Definition at line 12 of file pairwise_counts.cuh.

12{};

◆ higher

uint32_t cuddl::pairwise_counts::higher {}

this register is strictly higher than the other's in that bucket.

Definition at line 14 of file pairwise_counts.cuh.

14{};

◆ lower

uint32_t cuddl::pairwise_counts::lower {}

this register is strictly lower than the other's in that bucket.

Definition at line 10 of file pairwise_counts.cuh.

10{};

The documentation for this struct was generated from the following file: